FreeDiscovery Core
==================

FreeDiscovery Core is a Python package that aims to extend scikit-learn with information retrieval functionality.

Installation requires Python 2.7 or 3.5+, as well as,

 * numpy >= 1.10.1
 * scipy >= 0.16.1
 * pandas >= 0.18.0
 * scikit-learn >= 0.19.0

it can be installed with,

.. code:: bash

    pip install freediscovery[core]

Please refer to the :ref:`user manual <user_manual_section>` for a description of the available functionality.

.. toctree::
   :maxdepth: 1

   api
   examples/index
